@@ -1,5 +1,5 @@
-// Title: Statistique de test d'Anderson-Darling
-// Ref. (book or article): (voir le package nortest) Voir aussi Table 4.9 in Stephens (1986)
+// Title: The Anderson-Darling test
+// Ref. (book or article): See package nortest and also Table 4.9 p. 127 in M. A. Stephens, “Tests Based on EDF Statistics,” In: R. B. D’Agostino and M. A. Stephens, Eds., Goodness-of-Fit Techniques, Marcel Dekker, New York, 1986, pp. 97-193.
 
 #include <R.h>
 #include "Rmath.h"
@@ -13,7 +13,7 @@ extern "C" {
 // 4: bilateral test that rejects H0 only for small values of the test statistic
     alter[0] = 3;
     
-    int i, j=0, n=xlen[0];
+    int i, j = 0, n = xlen[0];
     if (getname[0] == 1) {
 // Here, INDICATE the name of your statistic
       const char *nom = "$AD^*$";
@@ -29,38 +29,38 @@ extern "C" {
 	name[j][0] = nom[j];
 	j++;
       }
-      for (i=j;i<50;i++) name[i][0] = space[0];
+      for (i = j; i < 50; i++) name[i][0] = space[0];
       return;
     }
 
-    if (n>3) {
+    if (n > 3) {
 // Computation of the value of the test statistic
     void R_rsort (double* x, int n);
     //    double pnorm(double q, double mean, double sd, int lower_tail, int log_p);
     double *ADa;
     ADa = new double[n];
-    double statAD, varX=0.0, sdX, meanX=0.0, sumAD=0.0, pval;
+    double statAD, varX = 0.0, sdX, meanX = 0.0, sumAD = 0.0, pval;
 
 
-    for (i=0;i<=(n-1);i++) meanX = meanX + x[i];
-    meanX =meanX/(double)n;
-    for (i=0;i<=(n-1);i++) varX = varX + R_pow(x[i],2.0);
-    varX = ((double)n)*(varX/(double)n - R_pow(meanX,2.0))/(double)(n-1); 
+    for (i = 0; i < n; i++) meanX = meanX + x[i];
+    meanX = meanX / (double)n;
+    for (i = 0; i < n; i++) varX = varX + R_pow(x[i], 2.0);
+    varX = ((double)n) * (varX / (double)n - R_pow(meanX, 2.0)) / (double)(n - 1); 
     sdX = sqrt(varX);
-    for (i=0;i<=(n-1);i++) ADa[i] = Rf_pnorm5((x[i]-meanX)/sdX,0.0,1.0,1,0);
-    R_rsort (ADa,n); // We sort the data
-    for (i=1;i<=n;i++) sumAD = sumAD + (2.0*(double)i-1.0)*log(ADa[i-1]) + (2.0*(double)n + 1.0-2.0*(double)i)*log(1.0-ADa[i-1]);
-    statAD = -((double)n + sumAD/(double)n);
+    for (i = 0; i < n; i++) ADa[i] = Rf_pnorm5((x[i] - meanX) / sdX, 0.0, 1.0, 1,0);
+    R_rsort (ADa, n); // We sort the data
+    for (i = 1; i <= n; i++) sumAD = sumAD + (2.0 * (double)i - 1.0) * log(ADa[i - 1]) + (2.0 * (double)n + 1.0 - 2.0 * (double)i) * log(1.0 - ADa[i - 1]);
+    statAD = -((double)n + sumAD / (double)n);
 
     statistic[0] = statAD; // Here is the test statistic value
 
-if (pvalcomp[0] == 1) {
+    if (pvalcomp[0] == 1) {
 	// If possible, computation of the p-value.
-	#include "pvalues/pvalue2.cpp"
-}
+#include "pvalues/pvalue2.cpp"
+    }
 
 // We take the decision to reject or not to reject the null hypothesis H0
-    for (i=0;i<=(nblevel[0]-1);i++) {
+    for (i = 0; i < nblevel[0]; i++) {
       if (usecrit[0] == 1) { // We use the provided critical values
 	if (statistic[0] > critvalR[i]) decision[i] = 1; else decision[i] = 0; // two.sided (but in this case only one possible critical value)
       } else {
